pub struct PendingDuration(/* private fields */);Expand description
A wrapper for floating-point representations of Duration to mitigate rounding errors.
Implementations
Sourceimpl PendingDuration
impl PendingDuration
Sourcepub fn from_duration(duration: Duration) -> Self
pub fn from_duration(duration: Duration) -> Self
Creates a new PendingDuration from a Duration.
Sourcepub fn try_to_duration(&self) -> Option<Duration>
pub fn try_to_duration(&self) -> Option<Duration>
Attempts to convert this instance into a Duration.
Returns None if the value is negative.
Sourcepub fn to_duration(&self) -> Duration
pub fn to_duration(&self) -> Duration
Sourcepub fn to_duration_with_clamp(&self, max: TimeTick) -> Duration
pub fn to_duration_with_clamp(&self, max: TimeTick) -> Duration
Converts to a Duration, clamping the result between 0 and max ticks.
Sourcepub fn to_duration_or_else<F>(&self, f: F) -> Duration
pub fn to_duration_or_else<F>(&self, f: F) -> Duration
Converts to a Duration, invoking the provided closure if the conversion fails.